/************************************************************************
Project(s):	            Infrastructure Growth Meta Analysis
Do File: 			    onlineappendix.do
Initial file by : 		Dhruv Jain
This version : 			Dhruv Jain
Created version: 		13/12/2023
Updated version: 	    
This version :			20/06/2024
Stata Version :			18
********************************************************************************
Description: This do file prepares the following outputs
*********************************************************************************/


*ssc install outreg2
*ssc install lassopack
* net install rddensity, from(https://raw.githubusercontent.com/rdpackages/rddensity/master/stata) replace


cd "$project"

use "data/mradata.dta", clear

*** create some aditional variables ***
gen se_1 = 1/se
gen se2= se*se	
gen z=0
gen y=1.96/finalcoeff if finalcoeff>0
replace y= -1.96/finalcoeff if finalcoeff<0

gen endocare = 1 - endogeneity
label var endocare "Dummy=1 if endogeneity addressed"

drop if tstat > 300

// Redefine sectors

//Create a separate dummy variable for public capital:

gen pubcap = 0
replace pubcap=1 if strpos(indepvar, "capital") 
replace pubcap=1 if strpos(indepvar, "Capital") 
replace pubcap=1 if strpos(indepvar, "investment") 
replace pubcap=1 if strpos(indepvar, "Investment") 
replace pubcap=1 if strpos(indepvar, "GFCF") 
replace pubcap=1 if strpos(indepvar, "govt. spending") 
replace pubcap=1 if strpos(indepvar, "Govt. spending") 
tab pubcap

//Sector classification: Digital (1), Energy (2), Transport (3), Cross-sectoral (4)

replace infra=4 if infra==0
tab infra


********************************************************************************
********************************************************************************



*** Figure A.1 ***

// digital
twoway (scatter se_1 finalcoeff if finalcoeff > -2  & finalcoeff < 3 & se_1< 200 &  infra == 1, msize(vsmall) mfc(none) mlc(blue%50)) (line se_1 z if finalcoeff > -2  & finalcoeff < 3 & se_1< 220 & infra == 1, lwidth(medium) lcolor(red)) ,  ytitle(1/Standard Error) xtitle(Coefficient) legend(off) || line y finalcoeff if finalcoeff > -2  & finalcoeff<0 & y<220,  lwidth(medium) lcolor(black) lpattern(dash) sort || line y finalcoeff if finalcoeff>0  & finalcoeff < 3 & y<220,  lwidth(medium) lcolor(black) lpattern(dash) sort scheme(s1mono) plotregion(lwidth(none))

graph export "results/oa_figa1a.png", replace

// energy
twoway (scatter se_1 finalcoeff if finalcoeff > -0.5  & finalcoeff < 3 & se_1< 200 &  infra == 2, msize(vsmall) mfc(none) mlc(blue%50)) (line se_1 z if finalcoeff > -0.5  & finalcoeff < 3 & se_1< 220 & infra == 2, lwidth(medium) lcolor(red)) , ytitle(1/Standard Error) xtitle(Coefficient) legend(off) || line y finalcoeff if finalcoeff > -0.5  & finalcoeff<0 & y<220,  lwidth(medium) lcolor(black) lpattern(dash) sort || line y finalcoeff if finalcoeff>0  & finalcoeff < 3 & y<220,  lwidth(medium) lcolor(black) lpattern(dash) sort scheme(s1mono) plotregion(lwidth(none))

graph export "results/oa_figa1b.png", replace

// transport
twoway (scatter se_1 finalcoeff if finalcoeff > -1  & finalcoeff < 3 & se_1< 200 &  infra == 3, msize(vsmall) mfc(none) mlc(blue%50)) (line se_1 z if finalcoeff > -1  & finalcoeff < 3 & se_1< 220 & infra == 3, lwidth(medium) lcolor(red)) , ytitle(1/Standard Error) xtitle(Coefficient) legend(off) || line y finalcoeff if finalcoeff > -1  & finalcoeff<0 & y<220,  lwidth(medium) lcolor(black) lpattern(dash) sort || line y finalcoeff if finalcoeff>0  & finalcoeff < 3 & y<220,  lwidth(medium) lcolor(black) lpattern(dash) sort scheme(s1mono) plotregion(lwidth(none))

graph export "results/oa_figa1c.png", replace

// cross-sector
twoway (scatter se_1 finalcoeff if finalcoeff > -3  & finalcoeff < 3 & se_1< 200 & infra == 4, msize(vsmall) mfc(none) mlc(blue%50)) (line se_1 z if finalcoeff > -0.5  & finalcoeff < 2 & se_1< 220 & infra == 4, lwidth(medium) lcolor(red)) , ytitle(1/Standard Error) xtitle(Coefficient) legend(off) || line y finalcoeff if finalcoeff > -0.5  & finalcoeff<0 & y<220,  lwidth(medium) lcolor(black) lpattern(dash) sort || line y finalcoeff if finalcoeff>0  & finalcoeff < 2 & y<220,  lwidth(medium) lcolor(black) lpattern(dash) sort scheme(s1mono) plotregion(lwidth(none))

graph export "results/oa_figa1d.png", replace



*** Figure A.2 ***


gen t=abs(coeffpaper/se) 
gen pv=2*(1-normal(abs(t)))
order pv, after(t)


// panel A: Transport - z stat
capture drop density1 xaxis1 ci1_1 ci1_2
kdens t if t <= 10 & infra==3, ll(0) ul(10) gen(density1 xaxis1) ci(ci1_1 ci1_2) nograph
twoway (hist t if t <= 10 & infra==3,  fcolor(gray%50) lcolor(blue%10) width(0.1) barwidth(0.09))  ///
(line density1 xaxis1,lcolor(black%90) lpattern(longdash) lwidth(medthick)), ///
legend(off) graphregion(color(white)) ylabel(, nogrid) title("", color(black)) xtitle("z-statistic") ytitle("Density") ///
xline(1.65 1.96 2.58, lwidth(medium) lcolor(maroon)) xlabel(0 1 1.65 "*" 1.96 "**" 2.58 "***" 3 4 5 6 7 8 9 10) scheme(s1mono)

graph export "results/oa_figa2a.png", replace

// panel B: Transport - p value
twoway (hist pv if pv <= .15 & pv>.0025 & infra==3, fcolor(lavender%40) lcolor(black%70) width(0.0025) barwidth(0.0025) ), ///
legend(off) graphregion(color(white)) ylabel(, nogrid) title("", color(black)) xtitle("p-value") ytitle("Density") ///
xline(.1 .05 .01, lwidth(medium) lcolor(maroon)) xlabel(0.01 .05 .1 .15 ) scheme(s1mono)

graph export "results/oa_figa2b.png", replace

// panel C: Digital - z stat
capture drop density1 xaxis1 ci1_1 ci1_2
kdens t if t <= 10 & infra==1, ll(0) ul(10) gen(density1 xaxis1) ci(ci1_1 ci1_2) nograph
twoway (hist t if t <= 10 & infra==1,  fcolor(gray%50) lcolor(blue%10) width(0.1) barwidth(0.09))  ///
(line density1 xaxis1,lcolor(black%90) lpattern(longdash) lwidth(medthick)), ///
legend(off) graphregion(color(white)) ylabel(, nogrid) title("", color(black)) xtitle("z-statistic") ytitle("Density") ///
xline(1.65 1.96 2.58, lwidth(medium) lcolor(maroon)) xlabel(0 1 1.65 "*" 1.96 "**" 2.58 "***" 3 4 5 6 7 8 9 10) scheme(s1mono)

graph export "results/oa_figa2c.png", replace

// panel D: Digital - p value 
twoway (hist pv if pv <= .15 & pv>.0025 & infra==1, fcolor(lavender%40) lcolor(black%70) width(0.0025) barwidth(0.0025) ), ///
legend(off) graphregion(color(white)) ylabel(, nogrid) title("", color(black)) xtitle("p-value") ytitle("Density") ///
xline(.1 .05 .01, lwidth(medium) lcolor(maroon)) xlabel(0.01 .05 .1 .15 ) scheme(s1mono)

graph export "results/oa_figa2d.png", replace

// panel E: Energy - z stat 
capture drop density1 xaxis1 ci1_1 ci1_2
kdens t if t <= 10 & infra==2, ll(0) ul(10) gen(density1 xaxis1) ci(ci1_1 ci1_2) nograph
twoway (hist t if t <= 10 & infra==2,  fcolor(gray%50) lcolor(blue%10) width(0.1) barwidth(0.09))  ///
(line density1 xaxis1,lcolor(black%90) lpattern(longdash) lwidth(medthick)), ///
legend(off) graphregion(color(white)) ylabel(, nogrid) title("", color(black)) xtitle("z-statistic") ytitle("Density") ///
xline(1.65 1.96 2.58, lwidth(medium) lcolor(maroon)) xlabel(0 1 1.65 "*" 1.96 "**" 2.58 "***" 3 4 5 6 7 8 9 10) scheme(s1mono)

graph export "results/oa_figa2e.png", replace

// panel F: Energy- p value 
twoway (hist pv if pv <= .15 & pv>.0025 & infra==2, fcolor(lavender%40) lcolor(black%70) width(0.0025) barwidth(0.0025) ), ///
legend(off) graphregion(color(white)) ylabel(, nogrid) title("", color(black)) xtitle("p-value") ytitle("Density") ///
xline(.1 .05 .01, lwidth(medium) lcolor(maroon)) xlabel(0.01 .05 .1 .15 ) scheme(s1mono)

graph export "results/oa_figa2f.png", replace


********************************************************************************


*** Table A.4 ***

tab link depvarcat, column

// please note that some categories were combined for easier presentation in the appendix version



*** Table A.5 ***


// panel A: binomial test 

*... 10 percent level

count if pv>=0.09 & pv<=0.1
local n=`r(N)'
count if pv>0.095 & pv<=0.1
local k=`r(N)'
display (1-binomial(`n',`k'-1,0.5))

*... 5 percent level

count if pv>=0.04 & pv<=0.05
local n=`r(N)'
count if pv>0.045 & pv<=0.05
local k=`r(N)'
display (1-binomial(`n',`k'-1,0.5))


*... 1 percent level

count if pv>=0.005 & pv<=0.015
local n=`r(N)'
count if pv>0.01 & pv<=0.015
local k=`r(N)'
display (1-binomial(`n',`k'-1,0.5))



// panel B: Cattaneo et al. (2020) discontinuity test

*... 10 percent 
rddensity pv, c(0.1) p(2)
display e(N_h_l)+e(N_h_r) // observations
display e(pv_q) // p value 

*... 5 percent 
rddensity pv, c(0.05) p(2) 
display e(N_h_l)+e(N_h_r) // observations
display e(pv_q) // p value 

*... 1 percent 
rddensity pv, c(0.01) p(2) 
display e(N_h_l)+e(N_h_r) // observations
display e(pv_q) // p value 



*** Table A.6 ***

// these tables are the binomial tests reported in Cattaneo et al. (2020) previously; we choose 5 different window lengths in the appendix table out of the 10 reported in the Stata output


*... 10 percent 
rddensity pv, c(0.1) p(2)

*... 5 percent 
rddensity pv, c(0.05) p(2) 

*... 1 percent 
rddensity pv, c(0.01) p(2) 



*** Tables A.8 to A.11 are also reported with the main results of Table 5 in the paper ***



*** Table A.12 ***

// Note: the coefficient of interest is given by the constant term in the following regressions 

local vars "publication academic govt international pubyear crosscountry developing time_med regiondata districtdata firmdata hhddata pf spatial iv did fe coint pubcap endocare "

foreach var of local vars {
	 summarize `var', meanonly
	 gen `var'_c = `var' - r(mean)
			 }
			 
global x *_c //moderators which are demeaned


// Panel A: Developed country sample only + RLASSO
qui rlasso finalcoeff se2 $x if infra==1 & developing==0 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) //digital
reg finalcoeff se2 `e(selected)' if infra==1 & developing==0 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea12.xls", append stats(coef se) excel addtext(Sample, "Digital")

qui rlasso finalcoeff se2 $x if infra==2 & developing==0 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) //energy
reg finalcoeff se2 `e(selected)' if infra==2 & developing==0 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea12.xls", append stats(coef se) excel addtext(Sample, "Energy")

qui rlasso finalcoeff se2 $x if infra==3 & developing==0 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) //transport
reg finalcoeff se2 `e(selected)' if infra==3 & developing==0 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea12.xls", append stats(coef se) excel addtext(Sample, "Transport")

qui rlasso finalcoeff se2 $x if infra==4 & developing==0 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) //cross-sector
reg finalcoeff se2 `e(selected)' if infra==4 & developing==0 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea12.xls", append stats(coef se) excel addtext(Sample, "Cross-Sector")
						
// Panel B: Developing country sample only + RLASSO
qui rlasso finalcoeff se2 $x if infra==1 & developing==1 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) //digital
reg finalcoeff se2 `e(selected)' if infra==1 & developing==1 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea12.xls", append stats(coef se) excel addtext(Sample, "Dev: Digital")

qui rlasso finalcoeff se2 $x if infra==2 & developing==1 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) //energy
reg finalcoeff se2 `e(selected)' if infra==2 & developing==1 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea12.xls", append stats(coef se) excel addtext(Sample, "Dev: Energy")

qui rlasso finalcoeff se2 $x if infra==3 & developing==1 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) //transport
reg finalcoeff se2 `e(selected)' if infra==3 & developing==1 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea12.xls", append stats(coef se) excel addtext(Sample, "Dev: Transport")

qui rlasso finalcoeff se2 $x if infra==4 & developing==1 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) //cross-sector
reg finalcoeff se2 `e(selected)' if infra==4 & developing==1 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea12.xls", append stats(coef se) excel addtext(Sample, "Dev: Cross-Sector")



*** Table A.13 ***


// Panel A: Developed country sample using RLASSO

// Digital x output micro 
qui rlasso finalcoeff se2 $x if infra == 1 & depvarcatcode==1 & developing==0 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) 
reg finalcoeff se2 `e(selected)' if infra == 1 & depvarcatcode==1 & developing==0 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea13.xls", alpha(0.01, 0.05, 0.1) symbol(***, **, *) bdec(4) title (PEESE estimates) sdec(3) append addtext(Sample, "Digital-micro")
		
// Digital x output macro 
qui rlasso finalcoeff se2 $x if infra == 1 & depvarcatcode==2 & developing==0 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) 
reg finalcoeff se2 `e(selected)' if infra == 1 & depvarcatcode==2 & developing==0 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea13.xls", alpha(0.01, 0.05, 0.1) symbol(***, **, *) bdec(4) title (PEESE estimates) sdec(3) append addtext(Sample, "Digital-macro")

/*
// Energy x output micro : no observations
qui rlasso finalcoeff se2 $x if infra == 2 & depvarcatcode==1 & developing==0 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) 
reg finalcoeff se2 `e(selected)' if infra == 2 & depvarcatcode==1 & developing==0 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea13.xls", alpha(0.01, 0.05, 0.1) symbol(***, **, *) bdec(4) title (PEESE estimates) sdec(3) append addtext(Sample, "Energy-micro")
*/

// Energy x output macro 
qui rlasso finalcoeff se2 $x if infra == 2 & depvarcatcode==2 & developing==0 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) 
reg finalcoeff se2 `e(selected)' if infra == 2 & depvarcatcode==2 & developing==0 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea13.xls", alpha(0.01, 0.05, 0.1) symbol(***, **, *) bdec(4) title (PEESE estimates) sdec(3) append addtext(Sample, "Energy-macro")
/*
// Energy x labor : only 2 observations
qui rlasso finalcoeff se2 $x if infra == 2 & depvarcatcode==3 & developing==0 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) 
reg finalcoeff se2 `e(selected)' if infra == 2 & depvarcatcode==3 & developing==0 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea13.xls", alpha(0.01, 0.05, 0.1) symbol(***, **, *) bdec(4) title (PEESE estimates) sdec(3) append addtext(Sample, "Energy-labor")

// Transport x output micro : only 2 observations
qui rlasso finalcoeff se2 $x if infra == 3 & depvarcatcode==1 & developing==0 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) 
reg finalcoeff se2 `e(selected)' if infra == 3 & depvarcatcode==1 & developing==0 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea13.xls", alpha(0.01, 0.05, 0.1) symbol(***, **, *) bdec(4) title (PEESE estimates) sdec(3) append addtext(Sample, "Transport-micro")
*/
// Transport x output macro 
qui rlasso finalcoeff se2 $x if infra == 3 & depvarcatcode==2 & developing==0 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) 
reg finalcoeff se2 `e(selected)' if infra == 3 & depvarcatcode==2 & developing==0 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea13.xls", alpha(0.01, 0.05, 0.1) symbol(***, **, *) bdec(4) title (PEESE estimates) sdec(3) append addtext(Sample, "Transport-macro")

// Transport x labor
qui rlasso finalcoeff se2 $x if infra == 3 & depvarcatcode==3 & developing==0 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) 
reg finalcoeff se2 `e(selected)' if infra == 3 & depvarcatcode==3 & developing==0 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea13.xls", alpha(0.01, 0.05, 0.1) symbol(***, **, *) bdec(4) title (PEESE estimates) sdec(3) append addtext(Sample, "Transport-labor")						
// Transport x trade // only 8 observations! RLASSO does not work!
/*qui rlasso finalcoeff se2 $x if infra == 3 & depvarcatcode==5 & developing==0 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) 
reg finalcoeff se2 `e(selected)' if infra == 3 & depvarcatcode==5 & developing==0 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea13.xls", alpha(0.01, 0.05, 0.1) symbol(***, **, *) bdec(4) title (PEESE estimates) sdec(3) append addtext(Sample, "Transport-trade")*/

// Transport x population
qui rlasso finalcoeff se2 $x if infra == 3 & depvarcatcode==7 & developing==0 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) 
reg finalcoeff se2 `e(selected)' if infra == 3 & depvarcatcode==7 & developing==0 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea13.xls", alpha(0.01, 0.05, 0.1) symbol(***, **, *) bdec(4) title (PEESE estimates) sdec(3) append addtext(Sample, "Transport-population")


							
// Panel B: Developing country sample only + RLASSO

// Digital x output micro 
qui rlasso finalcoeff se2 $x if infra == 1 & depvarcatcode==1 & developing==1 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) 
reg finalcoeff se2 `e(selected)' if infra == 1 & depvarcatcode==1 & developing==1 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea13.xls", alpha(0.01, 0.05, 0.1) symbol(***, **, *) bdec(4) title (PEESE estimates) sdec(3) append addtext(Sample, "Dev: Digital-micro")
		
// Digital x output macro 
qui rlasso finalcoeff se2 $x if infra == 1 & depvarcatcode==2 & developing==1 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) 
reg finalcoeff se2 `e(selected)' if infra == 1 & depvarcatcode==2 & developing==1 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea13.xls", alpha(0.01, 0.05, 0.1) symbol(***, **, *) bdec(4) title (PEESE estimates) sdec(3) append addtext(Sample, "Dev: Digital-macro")

// Energy x output micro 
qui rlasso finalcoeff se2 $x if infra == 2 & depvarcatcode==1 & developing==1 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) 
reg finalcoeff se2 `e(selected)' if infra == 2 & depvarcatcode==1 & developing==1 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea13.xls", alpha(0.01, 0.05, 0.1) symbol(***, **, *) bdec(4) title (PEESE estimates) sdec(3) append addtext(Sample, "Dev: Energy-micro")

// Energy x output macro 
qui rlasso finalcoeff se2 $x if infra == 2 & depvarcatcode==2 & developing==1 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) 
reg finalcoeff se2 `e(selected)' if infra == 2 & depvarcatcode==2 & developing==1 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea13.xls", alpha(0.01, 0.05, 0.1) symbol(***, **, *) bdec(4) title (PEESE estimates) sdec(3) append addtext(Sample, "Dev: Energy-macro")

// Energy x labor
qui rlasso finalcoeff se2 $x if infra == 2 & depvarcatcode==3 & developing==1 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) 
reg finalcoeff se2 `e(selected)' if infra == 2 & depvarcatcode==3 & developing==1 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea13.xls", alpha(0.01, 0.05, 0.1) symbol(***, **, *) bdec(4) title (PEESE estimates) sdec(3) append addtext(Sample, "Dev: Energy-labor")

// Transport x output micro 
qui rlasso finalcoeff se2 $x if infra == 3 & depvarcatcode==1 & developing==1 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) 
reg finalcoeff se2 `e(selected)' if infra == 3 & depvarcatcode==1 & developing==1 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea13.xls", alpha(0.01, 0.05, 0.1) symbol(***, **, *) bdec(4) title (PEESE estimates) sdec(3) append addtext(Sample, "Dev: Transport-micro")

// Transport x output macro 
qui rlasso finalcoeff se2 $x if infra == 3 & depvarcatcode==2 & developing==1 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) 
reg finalcoeff se2 `e(selected)' if infra == 3 & depvarcatcode==2 & developing==1 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea13.xls", alpha(0.01, 0.05, 0.1) symbol(***, **, *) bdec(4) title (PEESE estimates) sdec(3) append addtext(Sample, "Dev: Transport-macro")

// Transport x labor
qui rlasso finalcoeff se2 $x if infra == 3 & depvarcatcode==3 & developing==1 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) 
reg finalcoeff se2 `e(selected)' if infra == 3 & depvarcatcode==3 & developing==1 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea13.xls", alpha(0.01, 0.05, 0.1) symbol(***, **, *) bdec(4) title (PEESE estimates) sdec(3) append addtext(Sample, "Dev: Transport-labor")	

// Transport x trade
qui rlasso finalcoeff se2 $x if infra == 3 & depvarcatcode==5 & developing==1 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) 
reg finalcoeff se2 `e(selected)' if infra == 3 & depvarcatcode==5 & developing==1 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea13.xls", alpha(0.01, 0.05, 0.1) symbol(***, **, *) bdec(4) title (PEESE estimates) sdec(3) append addtext(Sample, "Dev: Transport-trade")

// Transport x population
qui rlasso finalcoeff se2 $x if infra == 3 & depvarcatcode==7 & developing==1 [aweight=se^(-2)], pnotpen(se2) robust cluster(id) maxpsiiter(5) 
reg finalcoeff se2 `e(selected)' if infra == 3 & depvarcatcode==7 & developing==1 [aweight=se^(-2)], cluster(id) robust
outreg2 using "results/oa_tablea13.xls", alpha(0.01, 0.05, 0.1) symbol(***, **, *) bdec(4) title (PEESE estimates) sdec(3) append addtext(Sample, "Dev: Transport-population")
