/************************************************************************
Project(s):	            Infrastructure Growth Meta Analysis
Do File: 			    onlineappendix_a2.do
Initial file by : 		Dhruv Jain
This version : 			Dhruv Jain
Created version: 		13/12/2023
Updated version: 	    
This version :			20/06/2024
Stata Version :			18
********************************************************************************
Description: This do file prepares the following outputs
*********************************************************************************/



cd "$project"

use "data/mradata.dta", clear

********************************************************************************
********************************************************************************

	*... no of estimates 

bysort id: egen estimates=count(finalcoeff)
label var estimates "no of estimates we took from the paper"


	*... proportion of papers published 

gen published=(publication==1)
label var published "dummy=1 if the paper is published"


	*... is author an academic?

// we use the variable "academic" already defined in the dataset


	*... is the study cross-country?

bysort id: egen cross=max(crosscountry)
label var cross "dummy=1 if study is cross-country"	


	*... no of countries 

// 3 studies have different number of countries for different estimates (I take the max within each study to have one unique number for each study) and 1 study does not have no of countries given in the paper but was conducted in various big cities around the world!

bysort id: egen noofcountries=max(countries)
label var noofcountries "no of countries in the study"


	*... developing country only
	
// some studies report estimates of developing, developed and full sample; I count them as studies involving developing countries

bysort id: egen devonly=max(developing)
label var devonly "dummy=1 if study includes only developing countries"


	*... microdata studies
	
// some studies use both microdata and aggregate data in some specifications. I count it as a study using micro data if any of the estimates are obtained using firm or hhd level dataset

bysort id: egen micro=max(microdata)
label var micro "dummy=1 if study uses microdata"

	*... decade of publication
	
gen py1990s=(pubyear<=1999)
gen py2000s=(pubyear>=2000 & pubyear<=2009)
gen py2010s=(pubyear>=2010 & pubyear<=2019)
gen py2020s=(pubyear>=2020)

label var py1990s "Dummy=1 if published before in 90s i.e. before 1999"
label var py2000s "Dummy=1 if published in 2000s i.e. between 2000-2009"
label var py2010s "Dummy=1 if published in 2010s i.e. between 2010-2019"
label var py2020s "Dummy=1 if published in 2020s i.e. after 2020"

	*... study reports causal estimates
	
// many studies report OLS and then some causal estimates... I count a study as reporting a causal estimate if any of the reported estimates have corrected for endogeneity

gen causal = 1 - endogeneity
label var causal "dummy=1 if the estimate is causal"

bysort id: egen endocorr=max(causal)
label var endocorr "dummy=1 if the study has corrected for endogeneity"


bysort id: egen iv_m=max(iv)
bysort id: egen did_m=max(did)
bysort id: egen rct_m=max(rct)
bysort id: egen rdd_m=max(rdd)


label var iv_m "dummy=1 if paper used IV"
label var did_m "dummy=1 if paper used DID"
label var rct_m "dummy=1 if paper used RCT"
label var rdd_m "dummy=1 if paper used RDD"


	*... dummy for top5 publication

gen top5=1 if source=="American Economic Review" | source=="Journal of Political Economy" | ///
source=="Review of Economic Studies " | source=="Review of Economic Studies" | ///
source=="Quarterly Journal of Economics"
replace top5=0 if top5==.
label var top5 "dummy=1 for top5 publication"


	*... dummy for top5 + top field journal
gen topj=1 if source=="American Economic Review" | source=="Journal of Political Economy" | ///
source=="Review of Economic Studies " | source=="Review of Economic Studies" | ///
source=="Quarterly Journal of Economics" | source==" Journal of Monetary Economics" | ///
source=="American Economic Journal: Economic Policy" | source=="Economic Journal" | ///
source=="Journal of Development Economics" | source==" Journal of Applied Econometrics" | ///
source=="Journal of International Economics" | source=="Journal of Monetary Economics" | ///
source=="Journal of Public Economics" | source=="Journal of Urban Economics" | ///
source=="The Review of Economics and Statistics" | source=="The Review of economics and statistics" | ///
source=="Journal of the European Economic Association" | source=="Review of Economics and Statistics" | ///
source=="The Economic Journal" | source==" Journal of economic growth"
replace topj=0 if topj==.
label var topj "dummy=1 for top journal papers"


	*... pubyear already defined
	
	*... income group
	
* tab incomegp

gen temp_ig=1 if incomegp=="High"
replace temp_ig=2 if incomegp=="LMIC" | incomegp=="UMIC"
replace temp_ig=3 if incomegp=="LIC"
replace temp_ig=4 if incomegp=="Various"
tab temp_ig

bysort id: egen minig=min(temp_ig)
bysort id: egen maxig=max(temp_ig)
gen x=(minig==maxig)
replace temp_ig=4 if x==0

gen high=(temp_ig==1)
gen mic=(temp_ig==2)
gen lic=(temp_ig==3)
gen variousig=(temp_ig==4)

label var high "Dummy=1 if study involves only high income countries"
label var mic "Dummy=1 if study involves only middle income countries"
label var lic "Dummy=1 if study involves only LIC"
label var variousig "Dummy=1 if study involves countries from >1 income groups"

drop temp_ig minig maxig x
	
	*... region
	
gen temp_r=1 if region=="North America" | region=="ECA"
replace temp_r=2 if region=="South Asia"
replace temp_r=3 if region=="SSA" | region=="Africa"
replace temp_r=4 if region=="EAP" 
replace temp_r=5 if region=="LAC"
replace temp_r=6 if region=="MENA" | region=="Various"

bysort id: egen minr=min(temp_r)
bysort id: egen maxr=max(temp_r)
gen x=(minr==maxr)
replace temp_r=6 if x==0

gen naeu=(temp_r==1)
gen sasia=(temp_r==2)
gen africa=(temp_r==3)
gen eap=(temp_r==4)
gen lac=(temp_r==5)
gen variousr=(temp_r==6)

label var naeu "Dummy=1 if study involves only North America or Europe"
label var sasia "Dummy=1 if study involves only South Asia"
label var africa "Dummy=1 if study involves only Africa"
label var eap "Dummy==1 if study involves only EAP region"
label var lac "Dummy==1 if study involves only LAC region"
label var variousr "Dummy=1 if study involves countries in >1 region"
	
drop temp_r minr maxr x

replace infra=4 if infra==0
tab infra


keep id estimates published top5 topj academic solo pubyear cross noofcountries ///
devonly micro endocorr iv_m rct_m did_m rdd_m infra high mic lic variousig ///
 naeu sasia africa eap lac variousr py*

duplicates drop

bysort id: gen srno=_n //gives serial number to obs with multiple infra within a given paper

duplicates tag id, gen(dup)

tab infra if dup==0

********************************************************************************
********************************************************************************

*... there are 26 papers out of 221 which have estimates from more than one infra sector (eg they have both transport and digital sector estimates). this complicates creating the summ table at the paper level but we will not count such papers and mention in footnote that these papers are not reflected in the summ stats.


local variables= "estimates published top5 topj academic solo pubyear py* cross noofcountries devonly naeu sasia africa eap lac variousr high mic lic variousig micro endocorr iv_m did_m rdd_m rct_m"

// column 1: full sample
estpost tabstat `variables' if srno==1, statistics(mean sd count) columns(statistics) 
esttab using "results/oa_tablea2.csv", append cells("mean sd count") nomtitle nonumber

// column: digital
estpost tabstat `variables' if infra==1 & dup==0, statistics(mean sd count) columns(statistics) 
esttab using "results/oa_tablea2.csv", append cells("mean sd count") nomtitle nonumber

// column: energy
estpost tabstat `variables' if infra==2 & dup==0, statistics(mean sd count) columns(statistics) 
esttab using "results/oa_tablea2.csv", append cells("mean sd count") nomtitle nonumber

// column: transport
estpost tabstat `variables' if infra==3 & dup==0, statistics(mean sd count) columns(statistics) 
esttab using "results/oa_tablea2.csv", append cells("mean sd count") nomtitle nonumber

// column: cross-sector
estpost tabstat `variables' if infra==4 & dup==0, statistics(mean sd count) columns(statistics) 
esttab using "results/oa_tablea2.csv", append cells("mean sd count") nomtitle nonumber

// I modify the table in excel and overleaf for final presentation in the online appendix
