/************************************************************************
Project(s):	            Infrastructure Growth Meta Analysis
Do File: 			    appendix_a3.do
Initial file by : 		Dhruv Jain
This version : 			Dhruv Jain
Created version: 		13/12/2023
Updated version: 	    
This version :			20/06/2024
Stata Version :			18
********************************************************************************
Description: This do file prepares the following outputs
*********************************************************************************/

cd "$project"

use "data/mradata.dta", clear


// define public and endocare as SS
replace infra=4 if infra==0
tab infra

gen endocare = 1 - endogeneity


********************************************************************************
/*.. This file creates summary stats of elasticities (both unweighted and weighted) for 
various cuts of the data */


*... create weights a la Brodeur et al. (AER 2023)
bysort id: egen x=count(id)
gen weight=round((1/x)*100000)
drop x
label var weight "Weights ala Brodeur et al. AER 2023"


matrix E=J(11,8,.)

gen tag1=1
gen tag2=1 if infra==1 // digital
gen tag3=1 if infra==2 // energy
gen tag4=1 if infra==3 // transport
gen tag5=1 if infra==4 // cross-sector
gen tag6=1 if infra==1 & depvarcatcode==1 // digital x output-micro
gen tag7=1 if infra==1 & depvarcatcode==2 // digital x output-macro
gen tag8=1 if infra==2 & depvarcatcode==1 // energy x output-micro
gen tag9=1 if infra==2 & depvarcatcode==2 // energy x output-macro
gen tag10=1 if infra==3 & depvarcatcode==1 //transport x output-micro
gen tag11=1 if infra==3 & depvarcatcode==2 // transport x output-macro


cd "results"


forval n=1/11{
	
matrix E[`n',1]=`n'
summ finalcoeff if tag`n'==1, d
matrix E[`n',2]=r(mean)
matrix E[`n',3]=r(sd)
matrix E[`n',4]=r(p50)
matrix E[`n',8]=r(N)
summ finalcoeff if tag`n'==1 [fw=weight], d
matrix E[`n',5]=r(mean)
matrix E[`n',6]=r(sd)
matrix E[`n',7]=r(p50)	
}


matsave E, saving replace

use "E.dta"

	rename c1 sample
	rename c2 mean_uw
	rename c3 sd_uw
	rename c4 med_uw
	rename c5 mean_w
	rename c6 sd_w
	rename c7 med_w
	rename c8 n

tostring sample, replace force

forval n=1/39{

if `n'==1 local sample "Full Sample"
if `n'==2 local sample "Digital"
if `n'==3 local sample "Energy"
if `n'==4 local sample "Transport"
if `n'==5 local sample "Cross-Sector"
if `n'==6 local sample "Digital x Output-micro"
if `n'==7 local sample "Digital x Output-macro"
if `n'==8 local sample "Energy x Output-micro"
if `n'==9 local sample "Energy x Output-macro"
if `n'==10 local sample "Transport x Output-micro"
if `n'==11 local sample "Transport x Output-macro"
replace sample="`sample'" if sample== "`n'"

}

*br //copy and paste in excel and modify as needed in overleaf to format it

export excel using "oa_tablea3.xls", firstrow(variables) replace

erase "E.dta"
