/************************************************************************
Project(s):	            Infrastructure Growth Meta Analysis
Do File: 			    onlineappendix_a7.do
Initial file by : 		Dhruv Jain
This version : 			Dhruv Jain
Created version: 		13/12/2023
Updated version: 	    
This version :			20/06/2024
Stata Version :			18
********************************************************************************
Description: This do file prepares the following outputs
*********************************************************************************/

cd "$project"

use "data/mradata.dta", clear

********************************************************************************

*... define public and endocare
replace infra=4 if infra==0
tab infra

gen endocare = 1 - endogeneity
label var endocare "Dummy=1 if estimate is causal (endogeneity is addressed)"

*... create weights a la Brodeur et al. (AER 2023)
bysort id: egen x=count(id)
gen weight=round((1/x)*100000)
drop x
label var weight "Weights ala Brodeur et al. AER 2023"

gen t=abs(coeffpaper/se)
label var t "z-stat ala Brodeur et al. 2023 AER"


*... dummies for significance levels
tab siglevel, gen(sig)
drop sig1
rename (sig2 sig3 sig4) (sig1 sig5 sig10)
label var sig1 "Dummy=1 if sig at 1%"
label var sig5 "Dummy=1 if sig at %%"
label var sig10 "Dummy=1 if sig at 10%"

*... other variables needed
gen published=(publication==1)
label var published "dummy=1 if the paper is published"


*... make one primary endogeneity method based on the paper
replace iv=0 if rct==1 & iv==1 //3 cases
replace did=0 if did==1 & iv==1 //16 cases (IV is the main method)
replace did=0 if did==1 & endocare==0 & (id==5|id==18|id==28|id==33|id==45) //cases where did was questioned and IV was employed
replace endocare=1 if did==1 & endocare==0 & (id==25|id==46) // DID is valid
replace endocare=1 if id==98 & endomethod=="IV"
// for cases where we have GMM==1 and IV==1, we treat GMM as the main method and replace iv=0
replace iv=0 if iv==1 & gmm==1 //75 cases (GMM main method)
replace endocare=1 if endomethod=="GMM" & id==61 
gen x=endocare-iv-did-rct-rdd-gmm

gen others=.
replace others=x if x==1
replace others=gmm if gmm==1
replace others=rct if rct==1
replace others=rdd if rdd==1
replace others=0 if others==.
label var others "Dummy=1 for endogeneity methods other than IV and DID"

drop x

// sanity check!
gen check=endocare-iv-did-others
tab check // should be zero

********************************************************************************

// regressions 

**** 10% level ****

logit sig10 solo published micro endocare if t>(1.65-0.3) & t<(1.65+0.3) [pw=weight], cluster(id) 
margins, dydx(*) post
outreg2 using "results/oa_tablea7.xls", append stats(coef se) excel addtext(Bandwidth, "[1.35 1.95]") nocons


qui logit sig10 solo published micro iv did others if t>(1.65-0.3) & t<(1.65+0.3) [pw=weight], cluster(id) 
margins, dydx(*) post
outreg2 using "results/oa_tablea7.xls", append stats(coef se) excel addtext(Bandwidth, "[1.35 1.95]") nocons

**** 5% level ****

qui logit sig5 solo published micro endocare if t>(1.96-0.3) & t<(1.96+0.3) [pw=weight], cluster(id) 
margins, dydx(*) post
outreg2 using "results/oa_tablea7.xls", append stats(coef se) excel addtext(Bandwidth, "[1.66 2.26]") nocons


qui logit sig5 solo published micro iv did others if t>(1.96-0.3) & t<(1.96+0.3) [pw=weight], cluster(id) 
margins, dydx(*) post
outreg2 using "results/oa_tablea7.xls", append stats(coef se) excel addtext(Bandwidth, "[1.66 2.26]") nocons

**** 1% level ****

qui logit sig1 solo published micro endocare if t>(2.58-0.3) & t<(2.58+0.3) [pw=weight], cluster(id) 
margins, dydx(*) post
outreg2 using "results/oa_tablea7.xls", append stats(coef se) excel addtext(Bandwidth, "[2.28 2.88]") nocons

qui logit sig1 solo published micro iv did others if t>(2.58-0.3) & t<(2.58+0.3) [pw=weight], cluster(id) 
margins, dydx(*) post
outreg2 using "results/oa_tablea7.xls", append stats(coef se) excel addtext(Bandwidth, "[2.28 2.88]") nocons
